@@ -1,11 +1,12 @@
 import { Scope, ScopeNode, store as storeImpl } from '@grafana/data';
-import { config } from '@grafana/runtime';
+import { config, locationService } from '@grafana/runtime';
 import { SceneRenderProfiler } from '@grafana/scenes';
 import { getDashboardSceneProfiler } from 'app/features/dashboard/services/DashboardProfiler';
 
 import { ScopesApiClient } from '../ScopesApiClient';
 import { ScopesServiceBase } from '../ScopesServiceBase';
 import { ScopesDashboardsService } from '../dashboards/ScopesDashboardsService';
+import { isCurrentPath } from '../dashboards/scopeNavgiationUtils';
 
 import {
   closeNodes,
@@ -18,7 +19,6 @@ import {
   treeNodeAtPath,
 } from './scopesTreeUtils';
 import { NodesMap, RecentScope, RecentScopeSchema, ScopeSchema, ScopesMap, SelectedScope, TreeNode } from './types';
-
 export const RECENT_SCOPES_KEY = 'grafana.scopes.recent';
 
 export interface ScopesSelectorServiceState {
@@ -362,7 +362,31 @@ export class ScopesSelectorService extends ScopesServiceBase<ScopesSelectorServi
 
     // Fetches both dashboards and scope navigations
     // We call this even if we have 0 scope because in that case it also closes the dashboard drawer.
-    this.dashboardsService.fetchDashboards(scopes.map((s) => s.scopeId));
+    this.dashboardsService.fetchDashboards(scopes.map((s) => s.scopeId)).then(() => {
+      // Redirect to first scopeNavigation if current URL isn't a scopeNavigation
+      const currentPath = locationService.getLocation().pathname;
+      const activeScopeNavigation = this.dashboardsService.state.scopeNavigations.find((s) => {
+        if (!('url' in s.spec) || typeof s.spec.url !== 'string') {
+          return false;
+        }
+        return isCurrentPath(currentPath, s.spec.url);
+      });
+
+      if (!activeScopeNavigation && this.dashboardsService.state.scopeNavigations.length > 0) {
+        // Redirect to the first available scopeNavigation
+        const firstScopeNavigation = this.dashboardsService.state.scopeNavigations[0];
+
+        if (
+          firstScopeNavigation &&
+          'url' in firstScopeNavigation.spec &&
+          typeof firstScopeNavigation.spec.url === 'string' &&
+          // Only redirect to dashboards TODO: Remove this once Logs Drilldown has Scopes support
+          firstScopeNavigation.spec.url.includes('/d/')
+        ) {
+          locationService.push(firstScopeNavigation.spec.url);
+        }
+      }
+    });
 
     if (scopes.length > 0) {
       const fetchedScopes = await this.apiClient.fetchMultipleScopes(scopes.map((s) => s.scopeId));
